addSuffix: Generic function to add a suffix to various objects like...

View source: R/deprecated_methods.R

addSuffixR Documentation

Generic function to add a suffix to various objects like parameters, code records, compartment names or a model (all previous objects at the same time). This makes it an extremely powerful function to combine 2 models or more (using function 'add'), that have similar equation, parameter or compartment names.

Description

'r lifecycle::badge("deprecated")'

Usage

addSuffix(object, suffix, separator, ...)

Arguments

object

generic object

suffix

suffix to be appended, single character value

separator

separator to use before the suffix, default is the underscore

...

extra arguments like 'model' if the changes need to be reflected in the model

Details

'addSuffix()' is deprecated in favor of 'add_suffix()'.

Value

updated object of the same class as the provided object, unless 'model' was specified, in that case the model is returned


campsismod documentation built on July 30, 2026, 9:06 a.m.