assert_single_character_string: Assert the given character vector is a single character...

View source: R/utilities.R

assert_single_character_stringR Documentation

Assert the given character vector is a single character string.

Description

Assert the given character vector is a single character string.

Usage

assert_single_character_string(x)

Arguments

x

single character string

Value

no return value


campsismod documentation built on July 30, 2026, 9:06 a.m.