flag_sampled_parameter_rows: Flag all parameter rows that have at least one parameter out...

View source: R/parameter_uncertainty_utils.R

flag_sampled_parameter_rowsR Documentation

Flag all parameter rows that have at least one parameter out of the specified range or that have a non positive definite OMEGA or SIGMA matrix.

Description

Flag all parameter rows that have at least one parameter out of the specified range or that have a non positive definite OMEGA or SIGMA matrix.

Usage

flag_sampled_parameter_rows(table, minMax, settings, parameters)

Arguments

table

a data frame returned by sampleMore

minMax

a data frame with min, max values for each parameter

settings

replication settings

parameters

double array parameters to check for positive definiteness


campsismod documentation built on July 30, 2026, 9:06 a.m.