getCompartmentIndex: Get the compartment index for the specified compartment name.

View source: R/deprecated_methods.R

getCompartmentIndexR Documentation

Get the compartment index for the specified compartment name.

Description

'r lifecycle::badge("deprecated")'

Usage

getCompartmentIndex(object, name)

Arguments

object

generic object that contains compartments information

name

compartment name

Details

'getCompartmentIndex()' is deprecated in favor of 'get_compartment_index()'.

Value

the corresponding compartment index


campsismod documentation built on July 30, 2026, 9:06 a.m.