getNameInModel: Get the name of the given parameter in the Campsis model.

View source: R/deprecated_methods.R

getNameInModelR Documentation

Get the name of the given parameter in the Campsis model.

Description

'r lifecycle::badge("deprecated")'

Usage

getNameInModel(x)

Arguments

x

element to know the name

Details

'getNameInModel()' is deprecated in favor of 'get_name_in_model()'.

Value

the name of this parameter


campsismod documentation built on July 30, 2026, 9:06 a.m.