get_compartment_index: Get the compartment index for the specified compartment name.

View source: R/generic.R

get_compartment_indexR Documentation

Get the compartment index for the specified compartment name.

Description

Get the compartment index for the specified compartment name.

Usage

get_compartment_index(object, name)

## S4 method for signature 'compartments,character'
get_compartment_index(object, name)

## S4 method for signature 'campsis_model,character'
get_compartment_index(object, name)

Arguments

object

generic object that contains compartments information

name

compartment name

Value

the corresponding compartment index


campsismod documentation built on July 30, 2026, 9:06 a.m.