get_mapping_matrix: Return a matrix filled in with OMEGA/SIGMA names to be mapped...

View source: R/parameter_uncertainty_utils.R

get_mapping_matrixR Documentation

Return a matrix filled in with OMEGA/SIGMA names to be mapped with the values. Nonexistent parameters are filled in with the empty string.

Description

Return a matrix filled in with OMEGA/SIGMA names to be mapped with the values. Nonexistent parameters are filled in with the empty string.

Usage

get_mapping_matrix(parameters, type)

Arguments

parameters

subset of parameters

type

type of parameter to map (omega or sigma)

Value

a matrix with the names of the OMEGA/SIGMA parameters


campsismod documentation built on July 30, 2026, 9:06 a.m.