get_name_in_model: Get the name of the given parameter in the Campsis model.

View source: R/parameter.R

get_name_in_modelR Documentation

Get the name of the given parameter in the Campsis model.

Description

Get the name of the given parameter in the Campsis model.

Usage

get_name_in_model(x)

## S4 method for signature 'theta'
get_name_in_model(x)

## S4 method for signature 'omega'
get_name_in_model(x)

## S4 method for signature 'sigma'
get_name_in_model(x)

Arguments

x

element to know the name

Value

the name of this parameter


campsismod documentation built on July 30, 2026, 9:06 a.m.