Rdocumentation
powered by
Learn R Programming
campsismod (version 1.4.0)
is_equation: Say if line in record is an equation not.
Description
Say if line in record is an equation not.
Usage
is_equation(x)
Value
logical value
Arguments
x
character value