Learn R Programming

campsismod (version 1.4.0)

is_strict_record_delimiter: Is strict record delimiter. A strict record delimiter is any line starting with [...] and followed by nothing but spaces or a possible comment.

Description

Is strict record delimiter. A strict record delimiter is any line starting with [...] and followed by nothing but spaces or a possible comment.

Usage

is_strict_record_delimiter(line)

Value

a logical value

Arguments

line

any line, single character value