match_double_array_parameter: Match double array parameter from list based on the name...

View source: R/parameters.R

match_double_array_parameterR Documentation

Match double array parameter from list based on the name instead of the index. If a match is found, its indexes are automatically copied.

Description

Match double array parameter from list based on the name instead of the index. If a match is found, its indexes are automatically copied.

Usage

match_double_array_parameter(object, x)

Arguments

object

parameters

x

double array parameter to match

Value

the same parameter is no match was found or the same parameter with updated indexes if a match was found


campsismod documentation built on July 30, 2026, 9:06 a.m.