match_single_array_parameter: Match single array parameter from list based on the name...

View source: R/parameters.R

match_single_array_parameterR Documentation

Match single array parameter from list based on the name instead of the index. If a match is found, its index is automatically copied.

Description

Match single array parameter from list based on the name instead of the index. If a match is found, its index is automatically copied.

Usage

match_single_array_parameter(object, x)

Arguments

object

parameters

x

single array parameter to match

Value

the same parameter is no match was found or the same parameter with updated index if a match was found


campsismod documentation built on July 30, 2026, 9:06 a.m.