methods_global_functions: A empty method only used to declare some of the global...

View source: R/global.R

methods_global_functionsR Documentation

A empty method only used to declare some of the global function definitions contained in the package 'methods', which are used intensively.

Description

A empty method only used to declare some of the global function definitions contained in the package 'methods', which are used intensively.

Usage

methods_global_functions()

Value

no return value


campsismod documentation built on Sept. 27, 2026, 5:07 p.m.