update_parameters: Update model parameters based on the parameters issued from...

View source: R/replicated_campsis_model.R

update_parametersR Documentation

Update model parameters based on the parameters issued from the model replication.

Description

Update model parameters based on the parameters issued from the model replication.

Usage

update_parameters(model, row)

Arguments

model

Campsis model

row

a data frame row containing the new parameter values

Value

updated Campsis model


campsismod documentation built on July 30, 2026, 9:06 a.m.