View source: R/deprecated_methods.R
| addSuffix | R Documentation |
'r lifecycle::badge("deprecated")'
addSuffix(object, suffix, separator, ...)
object |
generic object |
suffix |
suffix to be appended, single character value |
separator |
separator to use before the suffix, default is the underscore |
... |
extra arguments like 'model' if the changes need to be reflected in the model |
'addSuffix()' is deprecated in favor of 'add_suffix()'.
updated object of the same class as the provided object, unless 'model' was specified, in that case the model is returned
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.