`r lifecycle::badge("deprecated")`
addSuffix(object, suffix, separator, ...)updated object of the same class as the provided object, unless 'model' was specified, in that case the model is returned
generic object
suffix to be appended, single character value
separator to use before the suffix, default is the underscore
extra arguments like 'model' if the changes need to be reflected in the model
`addSuffix()` is deprecated in favor of `add_suffix()`.