Generic function to add a suffix to various objects like parameters, code records, compartment names or a model (all previous objects at the same time). This makes it an extremely powerful function to combine 2 models or more (using function 'add'), that have similar equation, parameter or compartment names.
add_suffix(object, suffix, separator = NULL, ...)# S4 method for parameters,character,character
add_suffix(object, suffix, separator = NULL, ...)
# S4 method for code_records,character,character
add_suffix(object, suffix, separator = NULL, ...)
# S4 method for code_record,character,character
add_suffix(object, suffix, separator = NULL, ...)
# S4 method for compartments,character,character
add_suffix(object, suffix, separator = NULL, ...)
# S4 method for campsis_model,character,character
add_suffix(object, suffix, separator = NULL, ...)
updated object of the same class as the provided object, unless 'model' was specified, in that case the model is returned
generic object
suffix to be appended, single character value
separator to use before the suffix, default is the underscore
extra arguments like 'model' if the changes need to be reflected in the model