Learn R Programming

campsismod (version 1.4.0)

get_name_in_model: Get the name of the given parameter in the Campsis model.

Description

Get the name of the given parameter in the Campsis model.

Usage

get_name_in_model(x)

# S4 method for theta get_name_in_model(x)

# S4 method for omega get_name_in_model(x)

# S4 method for sigma get_name_in_model(x)

Value

the name of this parameter

Arguments

x

element to know the name