hasExactMethod: Has exact method allows to check the existence of a S4 method in Campsis
based on its signature.
Description
Has exact method allows to check the existence of a S4 method in Campsis
based on its signature.
Usage
hasExactMethod(generic, signature, where = topenv(parent.frame()))
Arguments
- generic
generic function name
- signature
function signature
- where
where to search functions