Learn R Programming

campsismod (version 1.4.0)

match_double_array_parameter: Match double array parameter from list based on the name instead of the index. If a match is found, its indexes are automatically copied.

Description

Match double array parameter from list based on the name instead of the index. If a match is found, its indexes are automatically copied.

Usage

match_double_array_parameter(object, x)

Value

the same parameter is no match was found or the same parameter with updated indexes if a match was found

Arguments

object

parameters

x

double array parameter to match