Match double array parameter from list based on the name instead of the index. If a match is found, its indexes are automatically copied.
match_double_array_parameter(object, x)the same parameter is no match was found or the same parameter with updated indexes if a match was found
parameters
double array parameter to match