Learn R Programming

campsismod (version 1.4.0)

match_single_array_parameter: Match single array parameter from list based on the name instead of the index. If a match is found, its index is automatically copied.

Description

Match single array parameter from list based on the name instead of the index. If a match is found, its index is automatically copied.

Usage

match_single_array_parameter(object, x)

Value

the same parameter is no match was found or the same parameter with updated index if a match was found

Arguments

object

parameters

x

single array parameter to match