| methods_global_functions | R Documentation |
A empty method only used to declare some of the global function definitions contained in the package 'methods', which are used intensively.
methods_global_functions()
no return value
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.