methods_global_functions: A empty method only used to declare some of the global function definitions
contained in the package 'methods', which are used intensively.
Description
A empty method only used to declare some of the global function definitions
contained in the package 'methods', which are used intensively.
Usage
methods_global_functions()