Generic function for parameter sampling according to the minimum and maximum values. This function will sample parameters a first time and check if some parameters are out of range. Based on the success rate, it will sample more parameters to reach the desired number of rows.
sample_generic(fun, args, n, minMax, msg, settings, parameters = NULL)tibble with the sampled parameters (1 parameter per column + REPLICATE column)
function to call to sample parameters
arguments to pass to the function
number of rows to sample
a data frame with min, max values for each parameter
message template
replication settings
double array parameters to check for positive definiteness