Learn R Programming

campsismod (version 1.4.0)

update_parameters: Update model parameters based on the parameters issued from the model replication.

Description

Update model parameters based on the parameters issued from the model replication.

Usage

update_parameters(model, row)

Value

updated Campsis model

Arguments

model

Campsis model

row

a data frame row containing the new parameter values